# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: state.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='state.proto',
  package='io.casperlabs.casper.consensus.state',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bstate.proto\x12$io.casperlabs.casper.consensus.state\"5\n\x06SemVer\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\r\n\x05patch\x18\x03 \x01(\r\"\xbb\x08\n\x08\x43ontract\x12\x1d\n\x15\x63ontract_package_hash\x18\x01 \x01(\x0c\x12\x1a\n\x12\x63ontract_wasm_hash\x18\x02 \x01(\x0c\x12\x42\n\nnamed_keys\x18\x03 \x03(\x0b\x32..io.casperlabs.casper.consensus.state.NamedKey\x12O\n\x0c\x65ntry_points\x18\x04 \x03(\x0b\x32\x39.io.casperlabs.casper.consensus.state.Contract.EntryPoint\x12O\n\x10protocol_version\x18\x06 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\x1a\x8d\x06\n\nEntryPoint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12K\n\x04\x61rgs\x18\x02 \x03(\x0b\x32=.io.casperlabs.casper.consensus.state.Contract.EntryPoint.Arg\x12\x39\n\x03ret\x18\x03 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12R\n\x06public\x18\x04 \x01(\x0b\x32@.io.casperlabs.casper.consensus.state.Contract.EntryPoint.PublicH\x00\x12R\n\x06groups\x18\x05 \x01(\x0b\x32@.io.casperlabs.casper.consensus.state.Contract.EntryPoint.GroupsH\x00\x12X\n\x07session\x18\x06 \x01(\x0b\x32\x45.io.casperlabs.casper.consensus.state.Contract.EntryPoint.SessionTypeH\x01\x12Z\n\x08\x63ontract\x18\x07 \x01(\x0b\x32\x46.io.casperlabs.casper.consensus.state.Contract.EntryPoint.ContractTypeH\x01\x1aR\n\x03\x41rg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12=\n\x07\x63l_type\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1a\x08\n\x06Public\x1a\x15\n\x05Group\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\r\n\x0bSessionType\x1a\x0e\n\x0c\x43ontractType\x1aY\n\x06Groups\x12O\n\x06groups\x18\x01 \x03(\x0b\x32?.io.casperlabs.casper.consensus.state.Contract.EntryPoint.GroupB\x08\n\x06\x61\x63\x63\x65ssB\x12\n\x10\x65ntry_point_type\"N\n\x12\x43ontractVersionKey\x12\x1e\n\x16protocol_version_major\x18\x01 \x01(\r\x12\x18\n\x10\x63ontract_version\x18\x02 \x01(\r\"\xd5\x04\n\x0f\x43ontractPackage\x12\x42\n\naccess_key\x18\x01 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.URef\x12V\n\x0f\x61\x63tive_versions\x18\x02 \x03(\x0b\x32=.io.casperlabs.casper.consensus.state.ContractPackage.Version\x12S\n\x11\x64isabled_versions\x18\x03 \x03(\x0b\x32\x38.io.casperlabs.casper.consensus.state.ContractVersionKey\x12K\n\x06groups\x18\x04 \x03(\x0b\x32;.io.casperlabs.casper.consensus.state.ContractPackage.Group\x1ak\n\x07Version\x12I\n\x07version\x18\x01 \x01(\x0b\x32\x38.io.casperlabs.casper.consensus.state.ContractVersionKey\x12\x15\n\rcontract_hash\x18\x02 \x01(\x0c\x1a\x96\x01\n\x05Group\x12N\n\x05group\x18\x01 \x01(\x0b\x32?.io.casperlabs.casper.consensus.state.Contract.EntryPoint.Group\x12=\n\x05urefs\x18\x02 \x03(\x0b\x32..io.casperlabs.casper.consensus.state.Key.URef\"\x81\x0e\n\x06\x43LType\x12J\n\x0bsimple_type\x18\x01 \x01(\x0e\x32\x33.io.casperlabs.casper.consensus.state.CLType.SimpleH\x00\x12J\n\x0boption_type\x18\x02 \x01(\x0b\x32\x33.io.casperlabs.casper.consensus.state.CLType.OptionH\x00\x12\x46\n\tlist_type\x18\x03 \x01(\x0b\x32\x31.io.casperlabs.casper.consensus.state.CLType.ListH\x00\x12Q\n\x0f\x66ixed_list_type\x18\x04 \x01(\x0b\x32\x36.io.casperlabs.casper.consensus.state.CLType.FixedListH\x00\x12J\n\x0bresult_type\x18\x05 \x01(\x0b\x32\x33.io.casperlabs.casper.consensus.state.CLType.ResultH\x00\x12\x44\n\x08map_type\x18\x06 \x01(\x0b\x32\x30.io.casperlabs.casper.consensus.state.CLType.MapH\x00\x12J\n\x0btuple1_type\x18\x07 \x01(\x0b\x32\x33.io.casperlabs.casper.consensus.state.CLType.Tuple1H\x00\x12J\n\x0btuple2_type\x18\x08 \x01(\x0b\x32\x33.io.casperlabs.casper.consensus.state.CLType.Tuple2H\x00\x12J\n\x0btuple3_type\x18\t \x01(\x0b\x32\x33.io.casperlabs.casper.consensus.state.CLType.Tuple3H\x00\x12\x44\n\x08\x61ny_type\x18\n \x01(\x0b\x32\x30.io.casperlabs.casper.consensus.state.CLType.AnyH\x00\x1a\x45\n\x06Option\x12;\n\x05inner\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1a\x43\n\x04List\x12;\n\x05inner\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1aU\n\tFixedList\x12;\n\x05inner\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12\x0b\n\x03len\x18\x02 \x01(\r\x1a}\n\x06Result\x12\x38\n\x02ok\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12\x39\n\x03\x65rr\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1a}\n\x03Map\x12\x39\n\x03key\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1a\x45\n\x06Tuple1\x12;\n\x05type0\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1a\x82\x01\n\x06Tuple2\x12;\n\x05type0\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12;\n\x05type1\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1a\xbf\x01\n\x06Tuple3\x12;\n\x05type0\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12;\n\x05type1\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12;\n\x05type2\x18\x03 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x1a\x05\n\x03\x41ny\"\x85\x01\n\x06Simple\x12\x08\n\x04\x42OOL\x10\x00\x12\x07\n\x03I32\x10\x01\x12\x07\n\x03I64\x10\x02\x12\x06\n\x02U8\x10\x03\x12\x07\n\x03U32\x10\x04\x12\x07\n\x03U64\x10\x05\x12\x08\n\x04U128\x10\x06\x12\x08\n\x04U256\x10\x07\x12\x08\n\x04U512\x10\x08\x12\x08\n\x04UNIT\x10\t\x12\n\n\x06STRING\x10\n\x12\x07\n\x03KEY\x10\x0b\x12\x08\n\x04UREF\x10\x0c\x42\n\n\x08variants\"b\n\x07\x43LValue\x12=\n\x07\x63l_type\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12\x18\n\x10serialized_value\x18\x02 \x01(\x0c\"\xf5\x14\n\x0f\x43LValueInstance\x12=\n\x07\x63l_type\x18\x01 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.CLType\x12J\n\x05value\x18\x02 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x1a\xe3\t\n\x05Value\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\r\n\x03i32\x18\x02 \x01(\x05H\x00\x12\r\n\x03i64\x18\x03 \x01(\x03H\x00\x12\x0c\n\x02u8\x18\x04 \x01(\x05H\x00\x12\r\n\x03u32\x18\x05 \x01(\rH\x00\x12\r\n\x03u64\x18\x06 \x01(\x04H\x00\x12J\n\x04u128\x18\x07 \x01(\x0b\x32:.io.casperlabs.casper.consensus.state.CLValueInstance.U128H\x00\x12J\n\x04u256\x18\x08 \x01(\x0b\x32:.io.casperlabs.casper.consensus.state.CLValueInstance.U256H\x00\x12J\n\x04u512\x18\t \x01(\x0b\x32:.io.casperlabs.casper.consensus.state.CLValueInstance.U512H\x00\x12:\n\x04unit\x18\n \x01(\x0b\x32*.io.casperlabs.casper.consensus.state.UnitH\x00\x12\x13\n\tstr_value\x18\x0b \x01(\tH\x00\x12\x38\n\x03key\x18\x0c \x01(\x0b\x32).io.casperlabs.casper.consensus.state.KeyH\x00\x12>\n\x04uref\x18\r \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.URefH\x00\x12T\n\x0coption_value\x18\x0e \x01(\x0b\x32<.io.casperlabs.casper.consensus.state.CLValueInstance.OptionH\x00\x12P\n\nlist_value\x18\x0f \x01(\x0b\x32:.io.casperlabs.casper.consensus.state.CLValueInstance.ListH\x00\x12[\n\x10\x66ixed_list_value\x18\x10 \x01(\x0b\x32?.io.casperlabs.casper.consensus.state.CLValueInstance.FixedListH\x00\x12T\n\x0cresult_value\x18\x11 \x01(\x0b\x32<.io.casperlabs.casper.consensus.state.CLValueInstance.ResultH\x00\x12N\n\tmap_value\x18\x12 \x01(\x0b\x32\x39.io.casperlabs.casper.consensus.state.CLValueInstance.MapH\x00\x12T\n\x0ctuple1_value\x18\x13 \x01(\x0b\x32<.io.casperlabs.casper.consensus.state.CLValueInstance.Tuple1H\x00\x12T\n\x0ctuple2_value\x18\x14 \x01(\x0b\x32<.io.casperlabs.casper.consensus.state.CLValueInstance.Tuple2H\x00\x12T\n\x0ctuple3_value\x18\x15 \x01(\x0b\x32<.io.casperlabs.casper.consensus.state.CLValueInstance.Tuple3H\x00\x12\x15\n\x0b\x62ytes_value\x18\x16 \x01(\x0cH\x00\x42\x07\n\x05value\x1a\x15\n\x04U128\x12\r\n\x05value\x18\x01 \x01(\t\x1a\x15\n\x04U256\x12\r\n\x05value\x18\x01 \x01(\t\x1a\x15\n\x04U512\x12\r\n\x05value\x18\x01 \x01(\t\x1aT\n\x06Option\x12J\n\x05value\x18\x01 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x1aS\n\x04List\x12K\n\x06values\x18\x01 \x03(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x1ah\n\tFixedList\x12\x0e\n\x06length\x18\x01 \x01(\r\x12K\n\x06values\x18\x02 \x03(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x1a\xa8\x01\n\x06Result\x12I\n\x02ok\x18\x01 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.ValueH\x00\x12J\n\x03\x65rr\x18\x02 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.ValueH\x00\x42\x07\n\x05value\x1aU\n\x03Map\x12N\n\x06values\x18\x01 \x03(\x0b\x32>.io.casperlabs.casper.consensus.state.CLValueInstance.MapEntry\x1a\xa0\x01\n\x08MapEntry\x12H\n\x03key\x18\x01 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x12J\n\x05value\x18\x02 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x1aV\n\x06Tuple1\x12L\n\x07value_1\x18\x01 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x1a\xa4\x01\n\x06Tuple2\x12L\n\x07value_1\x18\x01 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x12L\n\x07value_2\x18\x02 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x1a\xf2\x01\n\x06Tuple3\x12L\n\x07value_1\x18\x01 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x12L\n\x07value_2\x18\x02 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\x12L\n\x07value_3\x18\x03 \x01(\x0b\x32;.io.casperlabs.casper.consensus.state.CLValueInstance.Value\"\x1c\n\x0c\x43ontractWasm\x12\x0c\n\x04wasm\x18\x01 \x01(\x0c\"\x82\x03\n\x0bStoredValue\x12\x41\n\x08\x63l_value\x18\x01 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.CLValueH\x00\x12@\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.AccountH\x00\x12\x42\n\x08\x63ontract\x18\x03 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.ContractH\x00\x12Q\n\x10\x63ontract_package\x18\x04 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ContractPackageH\x00\x12K\n\rcontract_wasm\x18\x05 \x01(\x0b\x32\x32.io.casperlabs.casper.consensus.state.ContractWasmH\x00\x42\n\n\x08variants\"\x8f\x03\n\x13StoredValueInstance\x12I\n\x08\x63l_value\x18\x01 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.CLValueInstanceH\x00\x12@\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.AccountH\x00\x12\x42\n\x08\x63ontract\x18\x03 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.ContractH\x00\x12Q\n\x10\x63ontract_package\x18\x04 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ContractPackageH\x00\x12K\n\rcontract_wasm\x18\x05 \x01(\x0b\x32\x32.io.casperlabs.casper.consensus.state.ContractWasmH\x00\x42\x07\n\x05value\"\xf8\x04\n\x05Value\x12\x13\n\tint_value\x18\x01 \x01(\x05H\x00\x12\x15\n\x0b\x62ytes_value\x18\x02 \x01(\x0cH\x00\x12\x41\n\x08int_list\x18\x03 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.IntListH\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12@\n\x07\x61\x63\x63ount\x18\x05 \x01(\x0b\x32-.io.casperlabs.casper.consensus.state.AccountH\x00\x12\x42\n\x08\x63ontract\x18\x06 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.ContractH\x00\x12G\n\x0bstring_list\x18\x07 \x01(\x0b\x32\x30.io.casperlabs.casper.consensus.state.StringListH\x00\x12\x43\n\tnamed_key\x18\x08 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.NamedKeyH\x00\x12?\n\x07\x62ig_int\x18\t \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigIntH\x00\x12\x38\n\x03key\x18\n \x01(\x0b\x32).io.casperlabs.casper.consensus.state.KeyH\x00\x12:\n\x04unit\x18\x0b \x01(\x0b\x32*.io.casperlabs.casper.consensus.state.UnitH\x00\x12\x14\n\nlong_value\x18\x0c \x01(\x04H\x00\x42\x07\n\x05value\"\x19\n\x07IntList\x12\x0e\n\x06values\x18\x01 \x03(\x05\"\x1c\n\nStringList\x12\x0e\n\x06values\x18\x01 \x03(\t\"*\n\x06\x42igInt\x12\r\n\x05value\x18\x01 \x01(\t\x12\x11\n\tbit_width\x18\x02 \x01(\r\"\xea\x03\n\x03Key\x12\x44\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x31.io.casperlabs.casper.consensus.state.Key.AddressH\x00\x12>\n\x04hash\x18\x02 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.HashH\x00\x12>\n\x04uref\x18\x03 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.URefH\x00\x1a\x1a\n\x07\x41\x64\x64ress\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0c\x1a\x14\n\x04Hash\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x1a\xe1\x01\n\x04URef\x12\x0c\n\x04uref\x18\x01 \x01(\x0c\x12R\n\raccess_rights\x18\x02 \x01(\x0e\x32;.io.casperlabs.casper.consensus.state.Key.URef.AccessRights\"w\n\x0c\x41\x63\x63\x65ssRights\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\x07\n\x03\x41\x44\x44\x10\x04\x12\x0c\n\x08READ_ADD\x10\x05\x12\x0e\n\nREAD_WRITE\x10\x03\x12\r\n\tADD_WRITE\x10\x06\x12\x12\n\x0eREAD_ADD_WRITE\x10\x07\x42\x07\n\x05value\"P\n\x08NamedKey\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x03key\x18\x02 \x01(\x0b\x32).io.casperlabs.casper.consensus.state.Key\"\xeb\x03\n\x07\x41\x63\x63ount\x12\x12\n\npublic_key\x18\x01 \x01(\x0c\x12\x42\n\nmain_purse\x18\x03 \x01(\x0b\x32..io.casperlabs.casper.consensus.state.Key.URef\x12\x42\n\nnamed_keys\x18\x04 \x03(\x0b\x32..io.casperlabs.casper.consensus.state.NamedKey\x12T\n\x0f\x61ssociated_keys\x18\x05 \x03(\x0b\x32;.io.casperlabs.casper.consensus.state.Account.AssociatedKey\x12Y\n\x11\x61\x63tion_thresholds\x18\x06 \x01(\x0b\x32>.io.casperlabs.casper.consensus.state.Account.ActionThresholds\x1a\x33\n\rAssociatedKey\x12\x12\n\npublic_key\x18\x01 \x01(\x0c\x12\x0e\n\x06weight\x18\x02 \x01(\r\x1aR\n\x10\x41\x63tionThresholds\x12\x1c\n\x14\x64\x65ployment_threshold\x18\x01 \x01(\r\x12 \n\x18key_management_threshold\x18\x02 \x01(\rJ\x04\x08\x02\x10\x03J\x04\x08\x07\x10\x08\"\x06\n\x04Unit\">\n\x0fProtocolVersion\x12\r\n\x05major\x18\x01 \x01(\r\x12\r\n\x05minor\x18\x02 \x01(\r\x12\r\n\x05patch\x18\x03 \x01(\rb\x06proto3'
)



_CLTYPE_SIMPLE = _descriptor.EnumDescriptor(
  name='Simple',
  full_name='io.casperlabs.casper.consensus.state.CLType.Simple',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOOL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='I32', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='I64', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U8', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U32', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U64', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U128', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U256', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U512', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNIT', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KEY', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UREF', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3523,
  serialized_end=3656,
)
_sym_db.RegisterEnumDescriptor(_CLTYPE_SIMPLE)

_KEY_UREF_ACCESSRIGHTS = _descriptor.EnumDescriptor(
  name='AccessRights',
  full_name='io.casperlabs.casper.consensus.state.Key.URef.AccessRights',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ADD', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_WRITE', index=5, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADD_WRITE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ADD_WRITE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8370,
  serialized_end=8489,
)
_sym_db.RegisterEnumDescriptor(_KEY_UREF_ACCESSRIGHTS)


_SEMVER = _descriptor.Descriptor(
  name='SemVer',
  full_name='io.casperlabs.casper.consensus.state.SemVer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='io.casperlabs.casper.consensus.state.SemVer.major', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor', full_name='io.casperlabs.casper.consensus.state.SemVer.minor', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch', full_name='io.casperlabs.casper.consensus.state.SemVer.patch', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=106,
)


_CONTRACT_ENTRYPOINT_ARG = _descriptor.Descriptor(
  name='Arg',
  full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Arg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Arg.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cl_type', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Arg.cl_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=1007,
)

_CONTRACT_ENTRYPOINT_PUBLIC = _descriptor.Descriptor(
  name='Public',
  full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Public',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1009,
  serialized_end=1017,
)

_CONTRACT_ENTRYPOINT_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Group.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1019,
  serialized_end=1040,
)

_CONTRACT_ENTRYPOINT_SESSIONTYPE = _descriptor.Descriptor(
  name='SessionType',
  full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.SessionType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1055,
)

_CONTRACT_ENTRYPOINT_CONTRACTTYPE = _descriptor.Descriptor(
  name='ContractType',
  full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.ContractType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1071,
)

_CONTRACT_ENTRYPOINT_GROUPS = _descriptor.Descriptor(
  name='Groups',
  full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Groups',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groups', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.Groups.groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1162,
)

_CONTRACT_ENTRYPOINT = _descriptor.Descriptor(
  name='EntryPoint',
  full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ret', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.ret', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.public', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.groups', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.session', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.contract', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONTRACT_ENTRYPOINT_ARG, _CONTRACT_ENTRYPOINT_PUBLIC, _CONTRACT_ENTRYPOINT_GROUP, _CONTRACT_ENTRYPOINT_SESSIONTYPE, _CONTRACT_ENTRYPOINT_CONTRACTTYPE, _CONTRACT_ENTRYPOINT_GROUPS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='access', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.access',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='entry_point_type', full_name='io.casperlabs.casper.consensus.state.Contract.EntryPoint.entry_point_type',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=411,
  serialized_end=1192,
)

_CONTRACT = _descriptor.Descriptor(
  name='Contract',
  full_name='io.casperlabs.casper.consensus.state.Contract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contract_package_hash', full_name='io.casperlabs.casper.consensus.state.Contract.contract_package_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_wasm_hash', full_name='io.casperlabs.casper.consensus.state.Contract.contract_wasm_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_keys', full_name='io.casperlabs.casper.consensus.state.Contract.named_keys', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_points', full_name='io.casperlabs.casper.consensus.state.Contract.entry_points', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.casper.consensus.state.Contract.protocol_version', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONTRACT_ENTRYPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=1192,
)


_CONTRACTVERSIONKEY = _descriptor.Descriptor(
  name='ContractVersionKey',
  full_name='io.casperlabs.casper.consensus.state.ContractVersionKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version_major', full_name='io.casperlabs.casper.consensus.state.ContractVersionKey.protocol_version_major', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_version', full_name='io.casperlabs.casper.consensus.state.ContractVersionKey.contract_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1194,
  serialized_end=1272,
)


_CONTRACTPACKAGE_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='io.casperlabs.casper.consensus.state.ContractPackage.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='io.casperlabs.casper.consensus.state.ContractPackage.Version.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_hash', full_name='io.casperlabs.casper.consensus.state.ContractPackage.Version.contract_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1719,
)

_CONTRACTPACKAGE_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='io.casperlabs.casper.consensus.state.ContractPackage.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='io.casperlabs.casper.consensus.state.ContractPackage.Group.group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='urefs', full_name='io.casperlabs.casper.consensus.state.ContractPackage.Group.urefs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1722,
  serialized_end=1872,
)

_CONTRACTPACKAGE = _descriptor.Descriptor(
  name='ContractPackage',
  full_name='io.casperlabs.casper.consensus.state.ContractPackage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key', full_name='io.casperlabs.casper.consensus.state.ContractPackage.access_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_versions', full_name='io.casperlabs.casper.consensus.state.ContractPackage.active_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled_versions', full_name='io.casperlabs.casper.consensus.state.ContractPackage.disabled_versions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='io.casperlabs.casper.consensus.state.ContractPackage.groups', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONTRACTPACKAGE_VERSION, _CONTRACTPACKAGE_GROUP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1872,
)


_CLTYPE_OPTION = _descriptor.Descriptor(
  name='Option',
  full_name='io.casperlabs.casper.consensus.state.CLType.Option',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inner', full_name='io.casperlabs.casper.consensus.state.CLType.Option.inner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2636,
  serialized_end=2705,
)

_CLTYPE_LIST = _descriptor.Descriptor(
  name='List',
  full_name='io.casperlabs.casper.consensus.state.CLType.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inner', full_name='io.casperlabs.casper.consensus.state.CLType.List.inner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2707,
  serialized_end=2774,
)

_CLTYPE_FIXEDLIST = _descriptor.Descriptor(
  name='FixedList',
  full_name='io.casperlabs.casper.consensus.state.CLType.FixedList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inner', full_name='io.casperlabs.casper.consensus.state.CLType.FixedList.inner', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='len', full_name='io.casperlabs.casper.consensus.state.CLType.FixedList.len', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2776,
  serialized_end=2861,
)

_CLTYPE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='io.casperlabs.casper.consensus.state.CLType.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='io.casperlabs.casper.consensus.state.CLType.Result.ok', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='err', full_name='io.casperlabs.casper.consensus.state.CLType.Result.err', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2863,
  serialized_end=2988,
)

_CLTYPE_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='io.casperlabs.casper.consensus.state.CLType.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.state.CLType.Map.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLType.Map.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2990,
  serialized_end=3115,
)

_CLTYPE_TUPLE1 = _descriptor.Descriptor(
  name='Tuple1',
  full_name='io.casperlabs.casper.consensus.state.CLType.Tuple1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type0', full_name='io.casperlabs.casper.consensus.state.CLType.Tuple1.type0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3117,
  serialized_end=3186,
)

_CLTYPE_TUPLE2 = _descriptor.Descriptor(
  name='Tuple2',
  full_name='io.casperlabs.casper.consensus.state.CLType.Tuple2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type0', full_name='io.casperlabs.casper.consensus.state.CLType.Tuple2.type0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type1', full_name='io.casperlabs.casper.consensus.state.CLType.Tuple2.type1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3189,
  serialized_end=3319,
)

_CLTYPE_TUPLE3 = _descriptor.Descriptor(
  name='Tuple3',
  full_name='io.casperlabs.casper.consensus.state.CLType.Tuple3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type0', full_name='io.casperlabs.casper.consensus.state.CLType.Tuple3.type0', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type1', full_name='io.casperlabs.casper.consensus.state.CLType.Tuple3.type1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type2', full_name='io.casperlabs.casper.consensus.state.CLType.Tuple3.type2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3322,
  serialized_end=3513,
)

_CLTYPE_ANY = _descriptor.Descriptor(
  name='Any',
  full_name='io.casperlabs.casper.consensus.state.CLType.Any',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3515,
  serialized_end=3520,
)

_CLTYPE = _descriptor.Descriptor(
  name='CLType',
  full_name='io.casperlabs.casper.consensus.state.CLType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='simple_type', full_name='io.casperlabs.casper.consensus.state.CLType.simple_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='option_type', full_name='io.casperlabs.casper.consensus.state.CLType.option_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_type', full_name='io.casperlabs.casper.consensus.state.CLType.list_type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_list_type', full_name='io.casperlabs.casper.consensus.state.CLType.fixed_list_type', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_type', full_name='io.casperlabs.casper.consensus.state.CLType.result_type', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_type', full_name='io.casperlabs.casper.consensus.state.CLType.map_type', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuple1_type', full_name='io.casperlabs.casper.consensus.state.CLType.tuple1_type', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuple2_type', full_name='io.casperlabs.casper.consensus.state.CLType.tuple2_type', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuple3_type', full_name='io.casperlabs.casper.consensus.state.CLType.tuple3_type', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any_type', full_name='io.casperlabs.casper.consensus.state.CLType.any_type', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLTYPE_OPTION, _CLTYPE_LIST, _CLTYPE_FIXEDLIST, _CLTYPE_RESULT, _CLTYPE_MAP, _CLTYPE_TUPLE1, _CLTYPE_TUPLE2, _CLTYPE_TUPLE3, _CLTYPE_ANY, ],
  enum_types=[
    _CLTYPE_SIMPLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='variants', full_name='io.casperlabs.casper.consensus.state.CLType.variants',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1875,
  serialized_end=3668,
)


_CLVALUE = _descriptor.Descriptor(
  name='CLValue',
  full_name='io.casperlabs.casper.consensus.state.CLValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cl_type', full_name='io.casperlabs.casper.consensus.state.CLValue.cl_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialized_value', full_name='io.casperlabs.casper.consensus.state.CLValue.serialized_value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3670,
  serialized_end=3768,
)


_CLVALUEINSTANCE_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.bool_value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i32', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.i32', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='i64', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.i64', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='u8', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.u8', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='u32', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.u32', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='u64', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.u64', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='u128', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.u128', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='u256', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.u256', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='u512', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.u512', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.unit', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='str_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.str_value', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.key', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uref', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.uref', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='option_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.option_value', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.list_value', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_list_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.fixed_list_value', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.result_value', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.map_value', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuple1_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.tuple1_value', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuple2_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.tuple2_value', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tuple3_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.tuple3_value', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.bytes_value', index=21,
      number=22, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Value.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3930,
  serialized_end=5181,
)

_CLVALUEINSTANCE_U128 = _descriptor.Descriptor(
  name='U128',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.U128',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.U128.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5183,
  serialized_end=5204,
)

_CLVALUEINSTANCE_U256 = _descriptor.Descriptor(
  name='U256',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.U256',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.U256.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5206,
  serialized_end=5227,
)

_CLVALUEINSTANCE_U512 = _descriptor.Descriptor(
  name='U512',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.U512',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.U512.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5229,
  serialized_end=5250,
)

_CLVALUEINSTANCE_OPTION = _descriptor.Descriptor(
  name='Option',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Option',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Option.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5252,
  serialized_end=5336,
)

_CLVALUEINSTANCE_LIST = _descriptor.Descriptor(
  name='List',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.List.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5338,
  serialized_end=5421,
)

_CLVALUEINSTANCE_FIXEDLIST = _descriptor.Descriptor(
  name='FixedList',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.FixedList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.FixedList.length', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.FixedList.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5423,
  serialized_end=5527,
)

_CLVALUEINSTANCE_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Result.ok', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='err', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Result.err', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Result.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5530,
  serialized_end=5698,
)

_CLVALUEINSTANCE_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Map.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5700,
  serialized_end=5785,
)

_CLVALUEINSTANCE_MAPENTRY = _descriptor.Descriptor(
  name='MapEntry',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.MapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.MapEntry.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.MapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5788,
  serialized_end=5948,
)

_CLVALUEINSTANCE_TUPLE1 = _descriptor.Descriptor(
  name='Tuple1',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_1', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple1.value_1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5950,
  serialized_end=6036,
)

_CLVALUEINSTANCE_TUPLE2 = _descriptor.Descriptor(
  name='Tuple2',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_1', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple2.value_1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_2', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple2.value_2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6039,
  serialized_end=6203,
)

_CLVALUEINSTANCE_TUPLE3 = _descriptor.Descriptor(
  name='Tuple3',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple3',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value_1', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple3.value_1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_2', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple3.value_2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_3', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.Tuple3.value_3', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6206,
  serialized_end=6448,
)

_CLVALUEINSTANCE = _descriptor.Descriptor(
  name='CLValueInstance',
  full_name='io.casperlabs.casper.consensus.state.CLValueInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cl_type', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.cl_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.CLValueInstance.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLVALUEINSTANCE_VALUE, _CLVALUEINSTANCE_U128, _CLVALUEINSTANCE_U256, _CLVALUEINSTANCE_U512, _CLVALUEINSTANCE_OPTION, _CLVALUEINSTANCE_LIST, _CLVALUEINSTANCE_FIXEDLIST, _CLVALUEINSTANCE_RESULT, _CLVALUEINSTANCE_MAP, _CLVALUEINSTANCE_MAPENTRY, _CLVALUEINSTANCE_TUPLE1, _CLVALUEINSTANCE_TUPLE2, _CLVALUEINSTANCE_TUPLE3, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3771,
  serialized_end=6448,
)


_CONTRACTWASM = _descriptor.Descriptor(
  name='ContractWasm',
  full_name='io.casperlabs.casper.consensus.state.ContractWasm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wasm', full_name='io.casperlabs.casper.consensus.state.ContractWasm.wasm', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6450,
  serialized_end=6478,
)


_STOREDVALUE = _descriptor.Descriptor(
  name='StoredValue',
  full_name='io.casperlabs.casper.consensus.state.StoredValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cl_value', full_name='io.casperlabs.casper.consensus.state.StoredValue.cl_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='io.casperlabs.casper.consensus.state.StoredValue.account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='io.casperlabs.casper.consensus.state.StoredValue.contract', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_package', full_name='io.casperlabs.casper.consensus.state.StoredValue.contract_package', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_wasm', full_name='io.casperlabs.casper.consensus.state.StoredValue.contract_wasm', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='variants', full_name='io.casperlabs.casper.consensus.state.StoredValue.variants',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6481,
  serialized_end=6867,
)


_STOREDVALUEINSTANCE = _descriptor.Descriptor(
  name='StoredValueInstance',
  full_name='io.casperlabs.casper.consensus.state.StoredValueInstance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cl_value', full_name='io.casperlabs.casper.consensus.state.StoredValueInstance.cl_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='io.casperlabs.casper.consensus.state.StoredValueInstance.account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='io.casperlabs.casper.consensus.state.StoredValueInstance.contract', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_package', full_name='io.casperlabs.casper.consensus.state.StoredValueInstance.contract_package', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_wasm', full_name='io.casperlabs.casper.consensus.state.StoredValueInstance.contract_wasm', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.StoredValueInstance.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6870,
  serialized_end=7269,
)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='io.casperlabs.casper.consensus.state.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='int_value', full_name='io.casperlabs.casper.consensus.state.Value.int_value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='io.casperlabs.casper.consensus.state.Value.bytes_value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_list', full_name='io.casperlabs.casper.consensus.state.Value.int_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='io.casperlabs.casper.consensus.state.Value.string_value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='io.casperlabs.casper.consensus.state.Value.account', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='io.casperlabs.casper.consensus.state.Value.contract', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_list', full_name='io.casperlabs.casper.consensus.state.Value.string_list', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_key', full_name='io.casperlabs.casper.consensus.state.Value.named_key', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='big_int', full_name='io.casperlabs.casper.consensus.state.Value.big_int', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.state.Value.key', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='io.casperlabs.casper.consensus.state.Value.unit', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='io.casperlabs.casper.consensus.state.Value.long_value', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.Value.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7272,
  serialized_end=7904,
)


_INTLIST = _descriptor.Descriptor(
  name='IntList',
  full_name='io.casperlabs.casper.consensus.state.IntList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.casper.consensus.state.IntList.values', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7906,
  serialized_end=7931,
)


_STRINGLIST = _descriptor.Descriptor(
  name='StringList',
  full_name='io.casperlabs.casper.consensus.state.StringList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='io.casperlabs.casper.consensus.state.StringList.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7933,
  serialized_end=7961,
)


_BIGINT = _descriptor.Descriptor(
  name='BigInt',
  full_name='io.casperlabs.casper.consensus.state.BigInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.BigInt.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bit_width', full_name='io.casperlabs.casper.consensus.state.BigInt.bit_width', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7963,
  serialized_end=8005,
)


_KEY_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='io.casperlabs.casper.consensus.state.Key.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='io.casperlabs.casper.consensus.state.Key.Address.account', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8213,
  serialized_end=8239,
)

_KEY_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='io.casperlabs.casper.consensus.state.Key.Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.casper.consensus.state.Key.Hash.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8241,
  serialized_end=8261,
)

_KEY_UREF = _descriptor.Descriptor(
  name='URef',
  full_name='io.casperlabs.casper.consensus.state.Key.URef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uref', full_name='io.casperlabs.casper.consensus.state.Key.URef.uref', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_rights', full_name='io.casperlabs.casper.consensus.state.Key.URef.access_rights', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KEY_UREF_ACCESSRIGHTS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8264,
  serialized_end=8489,
)

_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='io.casperlabs.casper.consensus.state.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='io.casperlabs.casper.consensus.state.Key.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.casper.consensus.state.Key.hash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uref', full_name='io.casperlabs.casper.consensus.state.Key.uref', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_KEY_ADDRESS, _KEY_HASH, _KEY_UREF, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.casper.consensus.state.Key.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8008,
  serialized_end=8498,
)


_NAMEDKEY = _descriptor.Descriptor(
  name='NamedKey',
  full_name='io.casperlabs.casper.consensus.state.NamedKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.casper.consensus.state.NamedKey.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.casper.consensus.state.NamedKey.key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8500,
  serialized_end=8580,
)


_ACCOUNT_ASSOCIATEDKEY = _descriptor.Descriptor(
  name='AssociatedKey',
  full_name='io.casperlabs.casper.consensus.state.Account.AssociatedKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='io.casperlabs.casper.consensus.state.Account.AssociatedKey.public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='io.casperlabs.casper.consensus.state.Account.AssociatedKey.weight', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8927,
  serialized_end=8978,
)

_ACCOUNT_ACTIONTHRESHOLDS = _descriptor.Descriptor(
  name='ActionThresholds',
  full_name='io.casperlabs.casper.consensus.state.Account.ActionThresholds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployment_threshold', full_name='io.casperlabs.casper.consensus.state.Account.ActionThresholds.deployment_threshold', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_management_threshold', full_name='io.casperlabs.casper.consensus.state.Account.ActionThresholds.key_management_threshold', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8980,
  serialized_end=9062,
)

_ACCOUNT = _descriptor.Descriptor(
  name='Account',
  full_name='io.casperlabs.casper.consensus.state.Account',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='io.casperlabs.casper.consensus.state.Account.public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_purse', full_name='io.casperlabs.casper.consensus.state.Account.main_purse', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_keys', full_name='io.casperlabs.casper.consensus.state.Account.named_keys', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='associated_keys', full_name='io.casperlabs.casper.consensus.state.Account.associated_keys', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_thresholds', full_name='io.casperlabs.casper.consensus.state.Account.action_thresholds', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNT_ASSOCIATEDKEY, _ACCOUNT_ACTIONTHRESHOLDS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8583,
  serialized_end=9074,
)


_UNIT = _descriptor.Descriptor(
  name='Unit',
  full_name='io.casperlabs.casper.consensus.state.Unit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9076,
  serialized_end=9082,
)


_PROTOCOLVERSION = _descriptor.Descriptor(
  name='ProtocolVersion',
  full_name='io.casperlabs.casper.consensus.state.ProtocolVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='io.casperlabs.casper.consensus.state.ProtocolVersion.major', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor', full_name='io.casperlabs.casper.consensus.state.ProtocolVersion.minor', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patch', full_name='io.casperlabs.casper.consensus.state.ProtocolVersion.patch', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9084,
  serialized_end=9146,
)

_CONTRACT_ENTRYPOINT_ARG.fields_by_name['cl_type'].message_type = _CLTYPE
_CONTRACT_ENTRYPOINT_ARG.containing_type = _CONTRACT_ENTRYPOINT
_CONTRACT_ENTRYPOINT_PUBLIC.containing_type = _CONTRACT_ENTRYPOINT
_CONTRACT_ENTRYPOINT_GROUP.containing_type = _CONTRACT_ENTRYPOINT
_CONTRACT_ENTRYPOINT_SESSIONTYPE.containing_type = _CONTRACT_ENTRYPOINT
_CONTRACT_ENTRYPOINT_CONTRACTTYPE.containing_type = _CONTRACT_ENTRYPOINT
_CONTRACT_ENTRYPOINT_GROUPS.fields_by_name['groups'].message_type = _CONTRACT_ENTRYPOINT_GROUP
_CONTRACT_ENTRYPOINT_GROUPS.containing_type = _CONTRACT_ENTRYPOINT
_CONTRACT_ENTRYPOINT.fields_by_name['args'].message_type = _CONTRACT_ENTRYPOINT_ARG
_CONTRACT_ENTRYPOINT.fields_by_name['ret'].message_type = _CLTYPE
_CONTRACT_ENTRYPOINT.fields_by_name['public'].message_type = _CONTRACT_ENTRYPOINT_PUBLIC
_CONTRACT_ENTRYPOINT.fields_by_name['groups'].message_type = _CONTRACT_ENTRYPOINT_GROUPS
_CONTRACT_ENTRYPOINT.fields_by_name['session'].message_type = _CONTRACT_ENTRYPOINT_SESSIONTYPE
_CONTRACT_ENTRYPOINT.fields_by_name['contract'].message_type = _CONTRACT_ENTRYPOINT_CONTRACTTYPE
_CONTRACT_ENTRYPOINT.containing_type = _CONTRACT
_CONTRACT_ENTRYPOINT.oneofs_by_name['access'].fields.append(
  _CONTRACT_ENTRYPOINT.fields_by_name['public'])
_CONTRACT_ENTRYPOINT.fields_by_name['public'].containing_oneof = _CONTRACT_ENTRYPOINT.oneofs_by_name['access']
_CONTRACT_ENTRYPOINT.oneofs_by_name['access'].fields.append(
  _CONTRACT_ENTRYPOINT.fields_by_name['groups'])
_CONTRACT_ENTRYPOINT.fields_by_name['groups'].containing_oneof = _CONTRACT_ENTRYPOINT.oneofs_by_name['access']
_CONTRACT_ENTRYPOINT.oneofs_by_name['entry_point_type'].fields.append(
  _CONTRACT_ENTRYPOINT.fields_by_name['session'])
_CONTRACT_ENTRYPOINT.fields_by_name['session'].containing_oneof = _CONTRACT_ENTRYPOINT.oneofs_by_name['entry_point_type']
_CONTRACT_ENTRYPOINT.oneofs_by_name['entry_point_type'].fields.append(
  _CONTRACT_ENTRYPOINT.fields_by_name['contract'])
_CONTRACT_ENTRYPOINT.fields_by_name['contract'].containing_oneof = _CONTRACT_ENTRYPOINT.oneofs_by_name['entry_point_type']
_CONTRACT.fields_by_name['named_keys'].message_type = _NAMEDKEY
_CONTRACT.fields_by_name['entry_points'].message_type = _CONTRACT_ENTRYPOINT
_CONTRACT.fields_by_name['protocol_version'].message_type = _PROTOCOLVERSION
_CONTRACTPACKAGE_VERSION.fields_by_name['version'].message_type = _CONTRACTVERSIONKEY
_CONTRACTPACKAGE_VERSION.containing_type = _CONTRACTPACKAGE
_CONTRACTPACKAGE_GROUP.fields_by_name['group'].message_type = _CONTRACT_ENTRYPOINT_GROUP
_CONTRACTPACKAGE_GROUP.fields_by_name['urefs'].message_type = _KEY_UREF
_CONTRACTPACKAGE_GROUP.containing_type = _CONTRACTPACKAGE
_CONTRACTPACKAGE.fields_by_name['access_key'].message_type = _KEY_UREF
_CONTRACTPACKAGE.fields_by_name['active_versions'].message_type = _CONTRACTPACKAGE_VERSION
_CONTRACTPACKAGE.fields_by_name['disabled_versions'].message_type = _CONTRACTVERSIONKEY
_CONTRACTPACKAGE.fields_by_name['groups'].message_type = _CONTRACTPACKAGE_GROUP
_CLTYPE_OPTION.fields_by_name['inner'].message_type = _CLTYPE
_CLTYPE_OPTION.containing_type = _CLTYPE
_CLTYPE_LIST.fields_by_name['inner'].message_type = _CLTYPE
_CLTYPE_LIST.containing_type = _CLTYPE
_CLTYPE_FIXEDLIST.fields_by_name['inner'].message_type = _CLTYPE
_CLTYPE_FIXEDLIST.containing_type = _CLTYPE
_CLTYPE_RESULT.fields_by_name['ok'].message_type = _CLTYPE
_CLTYPE_RESULT.fields_by_name['err'].message_type = _CLTYPE
_CLTYPE_RESULT.containing_type = _CLTYPE
_CLTYPE_MAP.fields_by_name['key'].message_type = _CLTYPE
_CLTYPE_MAP.fields_by_name['value'].message_type = _CLTYPE
_CLTYPE_MAP.containing_type = _CLTYPE
_CLTYPE_TUPLE1.fields_by_name['type0'].message_type = _CLTYPE
_CLTYPE_TUPLE1.containing_type = _CLTYPE
_CLTYPE_TUPLE2.fields_by_name['type0'].message_type = _CLTYPE
_CLTYPE_TUPLE2.fields_by_name['type1'].message_type = _CLTYPE
_CLTYPE_TUPLE2.containing_type = _CLTYPE
_CLTYPE_TUPLE3.fields_by_name['type0'].message_type = _CLTYPE
_CLTYPE_TUPLE3.fields_by_name['type1'].message_type = _CLTYPE
_CLTYPE_TUPLE3.fields_by_name['type2'].message_type = _CLTYPE
_CLTYPE_TUPLE3.containing_type = _CLTYPE
_CLTYPE_ANY.containing_type = _CLTYPE
_CLTYPE.fields_by_name['simple_type'].enum_type = _CLTYPE_SIMPLE
_CLTYPE.fields_by_name['option_type'].message_type = _CLTYPE_OPTION
_CLTYPE.fields_by_name['list_type'].message_type = _CLTYPE_LIST
_CLTYPE.fields_by_name['fixed_list_type'].message_type = _CLTYPE_FIXEDLIST
_CLTYPE.fields_by_name['result_type'].message_type = _CLTYPE_RESULT
_CLTYPE.fields_by_name['map_type'].message_type = _CLTYPE_MAP
_CLTYPE.fields_by_name['tuple1_type'].message_type = _CLTYPE_TUPLE1
_CLTYPE.fields_by_name['tuple2_type'].message_type = _CLTYPE_TUPLE2
_CLTYPE.fields_by_name['tuple3_type'].message_type = _CLTYPE_TUPLE3
_CLTYPE.fields_by_name['any_type'].message_type = _CLTYPE_ANY
_CLTYPE_SIMPLE.containing_type = _CLTYPE
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['simple_type'])
_CLTYPE.fields_by_name['simple_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['option_type'])
_CLTYPE.fields_by_name['option_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['list_type'])
_CLTYPE.fields_by_name['list_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['fixed_list_type'])
_CLTYPE.fields_by_name['fixed_list_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['result_type'])
_CLTYPE.fields_by_name['result_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['map_type'])
_CLTYPE.fields_by_name['map_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['tuple1_type'])
_CLTYPE.fields_by_name['tuple1_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['tuple2_type'])
_CLTYPE.fields_by_name['tuple2_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['tuple3_type'])
_CLTYPE.fields_by_name['tuple3_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLTYPE.oneofs_by_name['variants'].fields.append(
  _CLTYPE.fields_by_name['any_type'])
_CLTYPE.fields_by_name['any_type'].containing_oneof = _CLTYPE.oneofs_by_name['variants']
_CLVALUE.fields_by_name['cl_type'].message_type = _CLTYPE
_CLVALUEINSTANCE_VALUE.fields_by_name['u128'].message_type = _CLVALUEINSTANCE_U128
_CLVALUEINSTANCE_VALUE.fields_by_name['u256'].message_type = _CLVALUEINSTANCE_U256
_CLVALUEINSTANCE_VALUE.fields_by_name['u512'].message_type = _CLVALUEINSTANCE_U512
_CLVALUEINSTANCE_VALUE.fields_by_name['unit'].message_type = _UNIT
_CLVALUEINSTANCE_VALUE.fields_by_name['key'].message_type = _KEY
_CLVALUEINSTANCE_VALUE.fields_by_name['uref'].message_type = _KEY_UREF
_CLVALUEINSTANCE_VALUE.fields_by_name['option_value'].message_type = _CLVALUEINSTANCE_OPTION
_CLVALUEINSTANCE_VALUE.fields_by_name['list_value'].message_type = _CLVALUEINSTANCE_LIST
_CLVALUEINSTANCE_VALUE.fields_by_name['fixed_list_value'].message_type = _CLVALUEINSTANCE_FIXEDLIST
_CLVALUEINSTANCE_VALUE.fields_by_name['result_value'].message_type = _CLVALUEINSTANCE_RESULT
_CLVALUEINSTANCE_VALUE.fields_by_name['map_value'].message_type = _CLVALUEINSTANCE_MAP
_CLVALUEINSTANCE_VALUE.fields_by_name['tuple1_value'].message_type = _CLVALUEINSTANCE_TUPLE1
_CLVALUEINSTANCE_VALUE.fields_by_name['tuple2_value'].message_type = _CLVALUEINSTANCE_TUPLE2
_CLVALUEINSTANCE_VALUE.fields_by_name['tuple3_value'].message_type = _CLVALUEINSTANCE_TUPLE3
_CLVALUEINSTANCE_VALUE.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['bool_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['bool_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['i32'])
_CLVALUEINSTANCE_VALUE.fields_by_name['i32'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['i64'])
_CLVALUEINSTANCE_VALUE.fields_by_name['i64'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['u8'])
_CLVALUEINSTANCE_VALUE.fields_by_name['u8'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['u32'])
_CLVALUEINSTANCE_VALUE.fields_by_name['u32'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['u64'])
_CLVALUEINSTANCE_VALUE.fields_by_name['u64'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['u128'])
_CLVALUEINSTANCE_VALUE.fields_by_name['u128'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['u256'])
_CLVALUEINSTANCE_VALUE.fields_by_name['u256'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['u512'])
_CLVALUEINSTANCE_VALUE.fields_by_name['u512'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['unit'])
_CLVALUEINSTANCE_VALUE.fields_by_name['unit'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['str_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['str_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['key'])
_CLVALUEINSTANCE_VALUE.fields_by_name['key'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['uref'])
_CLVALUEINSTANCE_VALUE.fields_by_name['uref'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['option_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['option_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['list_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['list_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['fixed_list_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['fixed_list_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['result_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['result_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['map_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['map_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['tuple1_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['tuple1_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['tuple2_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['tuple2_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['tuple3_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['tuple3_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_VALUE.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_VALUE.fields_by_name['bytes_value'])
_CLVALUEINSTANCE_VALUE.fields_by_name['bytes_value'].containing_oneof = _CLVALUEINSTANCE_VALUE.oneofs_by_name['value']
_CLVALUEINSTANCE_U128.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_U256.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_U512.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_OPTION.fields_by_name['value'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_OPTION.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_LIST.fields_by_name['values'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_LIST.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_FIXEDLIST.fields_by_name['values'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_FIXEDLIST.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_RESULT.fields_by_name['ok'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_RESULT.fields_by_name['err'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_RESULT.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_RESULT.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_RESULT.fields_by_name['ok'])
_CLVALUEINSTANCE_RESULT.fields_by_name['ok'].containing_oneof = _CLVALUEINSTANCE_RESULT.oneofs_by_name['value']
_CLVALUEINSTANCE_RESULT.oneofs_by_name['value'].fields.append(
  _CLVALUEINSTANCE_RESULT.fields_by_name['err'])
_CLVALUEINSTANCE_RESULT.fields_by_name['err'].containing_oneof = _CLVALUEINSTANCE_RESULT.oneofs_by_name['value']
_CLVALUEINSTANCE_MAP.fields_by_name['values'].message_type = _CLVALUEINSTANCE_MAPENTRY
_CLVALUEINSTANCE_MAP.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_MAPENTRY.fields_by_name['key'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_MAPENTRY.fields_by_name['value'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_MAPENTRY.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_TUPLE1.fields_by_name['value_1'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_TUPLE1.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_TUPLE2.fields_by_name['value_1'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_TUPLE2.fields_by_name['value_2'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_TUPLE2.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE_TUPLE3.fields_by_name['value_1'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_TUPLE3.fields_by_name['value_2'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_TUPLE3.fields_by_name['value_3'].message_type = _CLVALUEINSTANCE_VALUE
_CLVALUEINSTANCE_TUPLE3.containing_type = _CLVALUEINSTANCE
_CLVALUEINSTANCE.fields_by_name['cl_type'].message_type = _CLTYPE
_CLVALUEINSTANCE.fields_by_name['value'].message_type = _CLVALUEINSTANCE_VALUE
_STOREDVALUE.fields_by_name['cl_value'].message_type = _CLVALUE
_STOREDVALUE.fields_by_name['account'].message_type = _ACCOUNT
_STOREDVALUE.fields_by_name['contract'].message_type = _CONTRACT
_STOREDVALUE.fields_by_name['contract_package'].message_type = _CONTRACTPACKAGE
_STOREDVALUE.fields_by_name['contract_wasm'].message_type = _CONTRACTWASM
_STOREDVALUE.oneofs_by_name['variants'].fields.append(
  _STOREDVALUE.fields_by_name['cl_value'])
_STOREDVALUE.fields_by_name['cl_value'].containing_oneof = _STOREDVALUE.oneofs_by_name['variants']
_STOREDVALUE.oneofs_by_name['variants'].fields.append(
  _STOREDVALUE.fields_by_name['account'])
_STOREDVALUE.fields_by_name['account'].containing_oneof = _STOREDVALUE.oneofs_by_name['variants']
_STOREDVALUE.oneofs_by_name['variants'].fields.append(
  _STOREDVALUE.fields_by_name['contract'])
_STOREDVALUE.fields_by_name['contract'].containing_oneof = _STOREDVALUE.oneofs_by_name['variants']
_STOREDVALUE.oneofs_by_name['variants'].fields.append(
  _STOREDVALUE.fields_by_name['contract_package'])
_STOREDVALUE.fields_by_name['contract_package'].containing_oneof = _STOREDVALUE.oneofs_by_name['variants']
_STOREDVALUE.oneofs_by_name['variants'].fields.append(
  _STOREDVALUE.fields_by_name['contract_wasm'])
_STOREDVALUE.fields_by_name['contract_wasm'].containing_oneof = _STOREDVALUE.oneofs_by_name['variants']
_STOREDVALUEINSTANCE.fields_by_name['cl_value'].message_type = _CLVALUEINSTANCE
_STOREDVALUEINSTANCE.fields_by_name['account'].message_type = _ACCOUNT
_STOREDVALUEINSTANCE.fields_by_name['contract'].message_type = _CONTRACT
_STOREDVALUEINSTANCE.fields_by_name['contract_package'].message_type = _CONTRACTPACKAGE
_STOREDVALUEINSTANCE.fields_by_name['contract_wasm'].message_type = _CONTRACTWASM
_STOREDVALUEINSTANCE.oneofs_by_name['value'].fields.append(
  _STOREDVALUEINSTANCE.fields_by_name['cl_value'])
_STOREDVALUEINSTANCE.fields_by_name['cl_value'].containing_oneof = _STOREDVALUEINSTANCE.oneofs_by_name['value']
_STOREDVALUEINSTANCE.oneofs_by_name['value'].fields.append(
  _STOREDVALUEINSTANCE.fields_by_name['account'])
_STOREDVALUEINSTANCE.fields_by_name['account'].containing_oneof = _STOREDVALUEINSTANCE.oneofs_by_name['value']
_STOREDVALUEINSTANCE.oneofs_by_name['value'].fields.append(
  _STOREDVALUEINSTANCE.fields_by_name['contract'])
_STOREDVALUEINSTANCE.fields_by_name['contract'].containing_oneof = _STOREDVALUEINSTANCE.oneofs_by_name['value']
_STOREDVALUEINSTANCE.oneofs_by_name['value'].fields.append(
  _STOREDVALUEINSTANCE.fields_by_name['contract_package'])
_STOREDVALUEINSTANCE.fields_by_name['contract_package'].containing_oneof = _STOREDVALUEINSTANCE.oneofs_by_name['value']
_STOREDVALUEINSTANCE.oneofs_by_name['value'].fields.append(
  _STOREDVALUEINSTANCE.fields_by_name['contract_wasm'])
_STOREDVALUEINSTANCE.fields_by_name['contract_wasm'].containing_oneof = _STOREDVALUEINSTANCE.oneofs_by_name['value']
_VALUE.fields_by_name['int_list'].message_type = _INTLIST
_VALUE.fields_by_name['account'].message_type = _ACCOUNT
_VALUE.fields_by_name['contract'].message_type = _CONTRACT
_VALUE.fields_by_name['string_list'].message_type = _STRINGLIST
_VALUE.fields_by_name['named_key'].message_type = _NAMEDKEY
_VALUE.fields_by_name['big_int'].message_type = _BIGINT
_VALUE.fields_by_name['key'].message_type = _KEY
_VALUE.fields_by_name['unit'].message_type = _UNIT
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['int_value'])
_VALUE.fields_by_name['int_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['bytes_value'])
_VALUE.fields_by_name['bytes_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['int_list'])
_VALUE.fields_by_name['int_list'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['account'])
_VALUE.fields_by_name['account'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['contract'])
_VALUE.fields_by_name['contract'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['string_list'])
_VALUE.fields_by_name['string_list'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['named_key'])
_VALUE.fields_by_name['named_key'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['big_int'])
_VALUE.fields_by_name['big_int'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['key'])
_VALUE.fields_by_name['key'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['unit'])
_VALUE.fields_by_name['unit'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['long_value'])
_VALUE.fields_by_name['long_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_KEY_ADDRESS.containing_type = _KEY
_KEY_HASH.containing_type = _KEY
_KEY_UREF.fields_by_name['access_rights'].enum_type = _KEY_UREF_ACCESSRIGHTS
_KEY_UREF.containing_type = _KEY
_KEY_UREF_ACCESSRIGHTS.containing_type = _KEY_UREF
_KEY.fields_by_name['address'].message_type = _KEY_ADDRESS
_KEY.fields_by_name['hash'].message_type = _KEY_HASH
_KEY.fields_by_name['uref'].message_type = _KEY_UREF
_KEY.oneofs_by_name['value'].fields.append(
  _KEY.fields_by_name['address'])
_KEY.fields_by_name['address'].containing_oneof = _KEY.oneofs_by_name['value']
_KEY.oneofs_by_name['value'].fields.append(
  _KEY.fields_by_name['hash'])
_KEY.fields_by_name['hash'].containing_oneof = _KEY.oneofs_by_name['value']
_KEY.oneofs_by_name['value'].fields.append(
  _KEY.fields_by_name['uref'])
_KEY.fields_by_name['uref'].containing_oneof = _KEY.oneofs_by_name['value']
_NAMEDKEY.fields_by_name['key'].message_type = _KEY
_ACCOUNT_ASSOCIATEDKEY.containing_type = _ACCOUNT
_ACCOUNT_ACTIONTHRESHOLDS.containing_type = _ACCOUNT
_ACCOUNT.fields_by_name['main_purse'].message_type = _KEY_UREF
_ACCOUNT.fields_by_name['named_keys'].message_type = _NAMEDKEY
_ACCOUNT.fields_by_name['associated_keys'].message_type = _ACCOUNT_ASSOCIATEDKEY
_ACCOUNT.fields_by_name['action_thresholds'].message_type = _ACCOUNT_ACTIONTHRESHOLDS
DESCRIPTOR.message_types_by_name['SemVer'] = _SEMVER
DESCRIPTOR.message_types_by_name['Contract'] = _CONTRACT
DESCRIPTOR.message_types_by_name['ContractVersionKey'] = _CONTRACTVERSIONKEY
DESCRIPTOR.message_types_by_name['ContractPackage'] = _CONTRACTPACKAGE
DESCRIPTOR.message_types_by_name['CLType'] = _CLTYPE
DESCRIPTOR.message_types_by_name['CLValue'] = _CLVALUE
DESCRIPTOR.message_types_by_name['CLValueInstance'] = _CLVALUEINSTANCE
DESCRIPTOR.message_types_by_name['ContractWasm'] = _CONTRACTWASM
DESCRIPTOR.message_types_by_name['StoredValue'] = _STOREDVALUE
DESCRIPTOR.message_types_by_name['StoredValueInstance'] = _STOREDVALUEINSTANCE
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['IntList'] = _INTLIST
DESCRIPTOR.message_types_by_name['StringList'] = _STRINGLIST
DESCRIPTOR.message_types_by_name['BigInt'] = _BIGINT
DESCRIPTOR.message_types_by_name['Key'] = _KEY
DESCRIPTOR.message_types_by_name['NamedKey'] = _NAMEDKEY
DESCRIPTOR.message_types_by_name['Account'] = _ACCOUNT
DESCRIPTOR.message_types_by_name['Unit'] = _UNIT
DESCRIPTOR.message_types_by_name['ProtocolVersion'] = _PROTOCOLVERSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SemVer = _reflection.GeneratedProtocolMessageType('SemVer', (_message.Message,), {
  'DESCRIPTOR' : _SEMVER,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.SemVer)
  })
_sym_db.RegisterMessage(SemVer)

Contract = _reflection.GeneratedProtocolMessageType('Contract', (_message.Message,), {

  'EntryPoint' : _reflection.GeneratedProtocolMessageType('EntryPoint', (_message.Message,), {

    'Arg' : _reflection.GeneratedProtocolMessageType('Arg', (_message.Message,), {
      'DESCRIPTOR' : _CONTRACT_ENTRYPOINT_ARG,
      '__module__' : 'state_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract.EntryPoint.Arg)
      })
    ,

    'Public' : _reflection.GeneratedProtocolMessageType('Public', (_message.Message,), {
      'DESCRIPTOR' : _CONTRACT_ENTRYPOINT_PUBLIC,
      '__module__' : 'state_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract.EntryPoint.Public)
      })
    ,

    'Group' : _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
      'DESCRIPTOR' : _CONTRACT_ENTRYPOINT_GROUP,
      '__module__' : 'state_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract.EntryPoint.Group)
      })
    ,

    'SessionType' : _reflection.GeneratedProtocolMessageType('SessionType', (_message.Message,), {
      'DESCRIPTOR' : _CONTRACT_ENTRYPOINT_SESSIONTYPE,
      '__module__' : 'state_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract.EntryPoint.SessionType)
      })
    ,

    'ContractType' : _reflection.GeneratedProtocolMessageType('ContractType', (_message.Message,), {
      'DESCRIPTOR' : _CONTRACT_ENTRYPOINT_CONTRACTTYPE,
      '__module__' : 'state_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract.EntryPoint.ContractType)
      })
    ,

    'Groups' : _reflection.GeneratedProtocolMessageType('Groups', (_message.Message,), {
      'DESCRIPTOR' : _CONTRACT_ENTRYPOINT_GROUPS,
      '__module__' : 'state_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract.EntryPoint.Groups)
      })
    ,
    'DESCRIPTOR' : _CONTRACT_ENTRYPOINT,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract.EntryPoint)
    })
  ,
  'DESCRIPTOR' : _CONTRACT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Contract)
  })
_sym_db.RegisterMessage(Contract)
_sym_db.RegisterMessage(Contract.EntryPoint)
_sym_db.RegisterMessage(Contract.EntryPoint.Arg)
_sym_db.RegisterMessage(Contract.EntryPoint.Public)
_sym_db.RegisterMessage(Contract.EntryPoint.Group)
_sym_db.RegisterMessage(Contract.EntryPoint.SessionType)
_sym_db.RegisterMessage(Contract.EntryPoint.ContractType)
_sym_db.RegisterMessage(Contract.EntryPoint.Groups)

ContractVersionKey = _reflection.GeneratedProtocolMessageType('ContractVersionKey', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTVERSIONKEY,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.ContractVersionKey)
  })
_sym_db.RegisterMessage(ContractVersionKey)

ContractPackage = _reflection.GeneratedProtocolMessageType('ContractPackage', (_message.Message,), {

  'Version' : _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
    'DESCRIPTOR' : _CONTRACTPACKAGE_VERSION,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.ContractPackage.Version)
    })
  ,

  'Group' : _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
    'DESCRIPTOR' : _CONTRACTPACKAGE_GROUP,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.ContractPackage.Group)
    })
  ,
  'DESCRIPTOR' : _CONTRACTPACKAGE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.ContractPackage)
  })
_sym_db.RegisterMessage(ContractPackage)
_sym_db.RegisterMessage(ContractPackage.Version)
_sym_db.RegisterMessage(ContractPackage.Group)

CLType = _reflection.GeneratedProtocolMessageType('CLType', (_message.Message,), {

  'Option' : _reflection.GeneratedProtocolMessageType('Option', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_OPTION,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.Option)
    })
  ,

  'List' : _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_LIST,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.List)
    })
  ,

  'FixedList' : _reflection.GeneratedProtocolMessageType('FixedList', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_FIXEDLIST,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.FixedList)
    })
  ,

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_RESULT,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.Result)
    })
  ,

  'Map' : _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_MAP,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.Map)
    })
  ,

  'Tuple1' : _reflection.GeneratedProtocolMessageType('Tuple1', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_TUPLE1,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.Tuple1)
    })
  ,

  'Tuple2' : _reflection.GeneratedProtocolMessageType('Tuple2', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_TUPLE2,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.Tuple2)
    })
  ,

  'Tuple3' : _reflection.GeneratedProtocolMessageType('Tuple3', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_TUPLE3,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.Tuple3)
    })
  ,

  'Any' : _reflection.GeneratedProtocolMessageType('Any', (_message.Message,), {
    'DESCRIPTOR' : _CLTYPE_ANY,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType.Any)
    })
  ,
  'DESCRIPTOR' : _CLTYPE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLType)
  })
_sym_db.RegisterMessage(CLType)
_sym_db.RegisterMessage(CLType.Option)
_sym_db.RegisterMessage(CLType.List)
_sym_db.RegisterMessage(CLType.FixedList)
_sym_db.RegisterMessage(CLType.Result)
_sym_db.RegisterMessage(CLType.Map)
_sym_db.RegisterMessage(CLType.Tuple1)
_sym_db.RegisterMessage(CLType.Tuple2)
_sym_db.RegisterMessage(CLType.Tuple3)
_sym_db.RegisterMessage(CLType.Any)

CLValue = _reflection.GeneratedProtocolMessageType('CLValue', (_message.Message,), {
  'DESCRIPTOR' : _CLVALUE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValue)
  })
_sym_db.RegisterMessage(CLValue)

CLValueInstance = _reflection.GeneratedProtocolMessageType('CLValueInstance', (_message.Message,), {

  'Value' : _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_VALUE,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.Value)
    })
  ,

  'U128' : _reflection.GeneratedProtocolMessageType('U128', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_U128,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.U128)
    })
  ,

  'U256' : _reflection.GeneratedProtocolMessageType('U256', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_U256,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.U256)
    })
  ,

  'U512' : _reflection.GeneratedProtocolMessageType('U512', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_U512,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.U512)
    })
  ,

  'Option' : _reflection.GeneratedProtocolMessageType('Option', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_OPTION,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.Option)
    })
  ,

  'List' : _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_LIST,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.List)
    })
  ,

  'FixedList' : _reflection.GeneratedProtocolMessageType('FixedList', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_FIXEDLIST,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.FixedList)
    })
  ,

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_RESULT,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.Result)
    })
  ,

  'Map' : _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_MAP,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.Map)
    })
  ,

  'MapEntry' : _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_MAPENTRY,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.MapEntry)
    })
  ,

  'Tuple1' : _reflection.GeneratedProtocolMessageType('Tuple1', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_TUPLE1,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.Tuple1)
    })
  ,

  'Tuple2' : _reflection.GeneratedProtocolMessageType('Tuple2', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_TUPLE2,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.Tuple2)
    })
  ,

  'Tuple3' : _reflection.GeneratedProtocolMessageType('Tuple3', (_message.Message,), {
    'DESCRIPTOR' : _CLVALUEINSTANCE_TUPLE3,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance.Tuple3)
    })
  ,
  'DESCRIPTOR' : _CLVALUEINSTANCE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.CLValueInstance)
  })
_sym_db.RegisterMessage(CLValueInstance)
_sym_db.RegisterMessage(CLValueInstance.Value)
_sym_db.RegisterMessage(CLValueInstance.U128)
_sym_db.RegisterMessage(CLValueInstance.U256)
_sym_db.RegisterMessage(CLValueInstance.U512)
_sym_db.RegisterMessage(CLValueInstance.Option)
_sym_db.RegisterMessage(CLValueInstance.List)
_sym_db.RegisterMessage(CLValueInstance.FixedList)
_sym_db.RegisterMessage(CLValueInstance.Result)
_sym_db.RegisterMessage(CLValueInstance.Map)
_sym_db.RegisterMessage(CLValueInstance.MapEntry)
_sym_db.RegisterMessage(CLValueInstance.Tuple1)
_sym_db.RegisterMessage(CLValueInstance.Tuple2)
_sym_db.RegisterMessage(CLValueInstance.Tuple3)

ContractWasm = _reflection.GeneratedProtocolMessageType('ContractWasm', (_message.Message,), {
  'DESCRIPTOR' : _CONTRACTWASM,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.ContractWasm)
  })
_sym_db.RegisterMessage(ContractWasm)

StoredValue = _reflection.GeneratedProtocolMessageType('StoredValue', (_message.Message,), {
  'DESCRIPTOR' : _STOREDVALUE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.StoredValue)
  })
_sym_db.RegisterMessage(StoredValue)

StoredValueInstance = _reflection.GeneratedProtocolMessageType('StoredValueInstance', (_message.Message,), {
  'DESCRIPTOR' : _STOREDVALUEINSTANCE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.StoredValueInstance)
  })
_sym_db.RegisterMessage(StoredValueInstance)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), {
  'DESCRIPTOR' : _VALUE,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Value)
  })
_sym_db.RegisterMessage(Value)

IntList = _reflection.GeneratedProtocolMessageType('IntList', (_message.Message,), {
  'DESCRIPTOR' : _INTLIST,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.IntList)
  })
_sym_db.RegisterMessage(IntList)

StringList = _reflection.GeneratedProtocolMessageType('StringList', (_message.Message,), {
  'DESCRIPTOR' : _STRINGLIST,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.StringList)
  })
_sym_db.RegisterMessage(StringList)

BigInt = _reflection.GeneratedProtocolMessageType('BigInt', (_message.Message,), {
  'DESCRIPTOR' : _BIGINT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.BigInt)
  })
_sym_db.RegisterMessage(BigInt)

Key = _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {

  'Address' : _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
    'DESCRIPTOR' : _KEY_ADDRESS,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key.Address)
    })
  ,

  'Hash' : _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
    'DESCRIPTOR' : _KEY_HASH,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key.Hash)
    })
  ,

  'URef' : _reflection.GeneratedProtocolMessageType('URef', (_message.Message,), {
    'DESCRIPTOR' : _KEY_UREF,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key.URef)
    })
  ,
  'DESCRIPTOR' : _KEY,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Key)
  })
_sym_db.RegisterMessage(Key)
_sym_db.RegisterMessage(Key.Address)
_sym_db.RegisterMessage(Key.Hash)
_sym_db.RegisterMessage(Key.URef)

NamedKey = _reflection.GeneratedProtocolMessageType('NamedKey', (_message.Message,), {
  'DESCRIPTOR' : _NAMEDKEY,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.NamedKey)
  })
_sym_db.RegisterMessage(NamedKey)

Account = _reflection.GeneratedProtocolMessageType('Account', (_message.Message,), {

  'AssociatedKey' : _reflection.GeneratedProtocolMessageType('AssociatedKey', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNT_ASSOCIATEDKEY,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Account.AssociatedKey)
    })
  ,

  'ActionThresholds' : _reflection.GeneratedProtocolMessageType('ActionThresholds', (_message.Message,), {
    'DESCRIPTOR' : _ACCOUNT_ACTIONTHRESHOLDS,
    '__module__' : 'state_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Account.ActionThresholds)
    })
  ,
  'DESCRIPTOR' : _ACCOUNT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Account)
  })
_sym_db.RegisterMessage(Account)
_sym_db.RegisterMessage(Account.AssociatedKey)
_sym_db.RegisterMessage(Account.ActionThresholds)

Unit = _reflection.GeneratedProtocolMessageType('Unit', (_message.Message,), {
  'DESCRIPTOR' : _UNIT,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.Unit)
  })
_sym_db.RegisterMessage(Unit)

ProtocolVersion = _reflection.GeneratedProtocolMessageType('ProtocolVersion', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLVERSION,
  '__module__' : 'state_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.casper.consensus.state.ProtocolVersion)
  })
_sym_db.RegisterMessage(ProtocolVersion)


# @@protoc_insertion_point(module_scope)
